//	ColourChooser.h - Simple colour chooser window.
//	----------------------------------------------------------------------------
//	This file is part of Motion Composition Tool, a simple application for
//	creating simple abstract animations.
//	Copyright (c) 2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef COLOURCHOOSER_H_
#define COLOURCHOOSER_H_

#include "juce.h"

class Window;

///	Simple colour chooser window.
class ColourChooser : public Component,
					  public ButtonListener,
					  public ChangeListener
{
  public:
	///	Constructor.
	ColourChooser(Window *parentComp, int colour);
	///	Destructor.
	~ColourChooser();

	///	Places the Components correctly.
	void resized();

	///	Called when Ok or Cancel is clicked.
	void buttonClicked(Button *button);
	///	Called when the colour changes.
	void changeListenerCallback(void *object);

	///	Returns whether or not the user clicked ok.
	bool isOkay() const {return retval;};
  private:
	///	Pointer to the main window.
	Window *parent;
	///	Which colour we're affecting.
	int colour;

	///	The ColourSelector.
	ColourSelector *colourSelector;
	///	The Cancel button.
	TextButton *cancel;
	///	The Ok button.
	TextButton *ok;

	///	Whether or not the user clicked ok to close the window.
	bool retval;
};

#endif
